@@ -2,6 +2,7 @@
 #define FORMTASKLISTNAVIGATOR_H
 
 #include <QWidget>
+class QMenuBar;
 
 namespace Ui {
 class FormTaskListNavigator;
@@ -31,9 +32,13 @@ private slots:
 
     void on_buttonNote_clicked();
 
+    void triggered(QAction* action);
+
 private:
     Ui::FormTaskListNavigator *ui;
     int folderId;
+    QMenuBar* menuBar;
+    QAction* deleteFolderAction;
 };
 
 #endif // FORMTASKLISTNAVIGATOR_H
